flutter_scroll_shadow library
Adds ScrollShadow widget to add shadows to a scrollable child. Supports ScrollController and vertical or horizontal orientation.
Classes
- ScrollShadow
-
Wraps a scrollable child in
ScrollShadows.
Adds ScrollShadow widget to add shadows to a scrollable child. Supports ScrollController and vertical or horizontal orientation.
ScrollShadows.