ScrollShadow class

Wraps a scrollable child in ScrollShadows.

Inheritance

Constructors

ScrollShadow({Key? key, double size = 6.0, Color color = Colors.black38, required Widget child, Duration duration = const Duration(milliseconds: 250), Curve fadeInCurve = Curves.easeIn, Curve fadeOutCurve = Curves.easeOut, bool ignoreInteraction = true})
Wraps a scrollable child in ScrollShadows.
const

Properties

child Widget
The scrollable child contained by the ScrollShadow.
final
color Color
color determines rendered color of shadows.
final
duration Duration
The duration for the animation of shadow visibility changes.
final
fadeInCurve Curve
The animation Curve to use for shadow appearance.
final
fadeOutCurve Curve
The animation Curve to use for shadow disappearance.
final
hashCode int
The hash code for this object.
no setterinherited
ignoreInteraction bool
Determines if shadow is wrapped inside a IgnorePointer widget, so that all touch events with the shadow will be ignored.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
size is a double that represents the size of shadows in logical pixels.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ScrollShadow>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited